@@ -43,3 +43,9 @@ class Admin(Module):
 
     def stopWS(self):
         return self.web3.manager.request_blocking("admin_stopWS", [])
+
+    def getProgramVersion(self):
+        return self.web3.manager.request_blocking("admin_getProgramVersion",[])
+
+    def getSchnorrNIZKProve(self):
+        return self.web3.manager.request_blocking("admin_getSchnorrNIZKProve", [])
\ No newline at end of file
